@@ -1,10 +1,10 @@
 from collections.abc import Iterable
-from typing import Optional
+from typing import Optional, List
 
 from discord import Reaction, Message, Member, RawReactionActionEvent
 
 from discordmenu.embed.emoji import DEFAULT_EMBED_MENU_EMOJI_CONFIG, EmbedMenuEmojiConfig
-from discordmenu.emoji_cache import discord_emoji_to_emoji_name
+from discordmenu.emoji.emoji import discord_emoji_to_emoji_name
 
 
 class ReactionFilter:
@@ -43,7 +43,6 @@ class ValidEmojiReactionFilter(ReactionFilter):
 
     async def _allow_reaction(self, message: Message, reaction: Reaction, member: Member):
         valid_emoji_reaction = discord_emoji_to_emoji_name(reaction.emoji) in self.valid_emoji_names
-        print("valid emo", valid_emoji_reaction)
         return valid_emoji_reaction
 
     async def _allow_reaction_raw(self, message: Message, reaction: RawReactionActionEvent):
@@ -77,3 +76,19 @@ class MessageOwnerReactionFilter(ReactionFilter):
         if reaction.guild_id:
             return reaction.member.id == self.original_author_id
         return True
+
+
+class FriendReactionFilter(ReactionFilter):
+    def __init__(self, original_author_id: int, friends_ids: List[str], filters: Optional[ReactionFilter] = None):
+        super().__init__(filters)
+        self.original_author_id = original_author_id
+        self.friend_ids = friends_ids
+
+    async def _allow_reaction(self, message: Message, reaction: Reaction, member: Member):
+        # return await friend_ids(self.original_author_id, member.id)
+        print("firend", self.friend_ids, member.id)
+        return member.id in self.friend_ids
+
+    async def _allow_reaction_raw(self, message: Message, reaction: RawReactionActionEvent):
+        # return self.friend_ids(self.original_author_id, reaction.member.id)
+        return reaction.member.id in self.friend_ids
